@@ -1,17 +1,17 @@
 impute.smd.oneoutlook <-
-function(table, whichoutlook, smdassigned){
-  ## function called by impute.smd()
-  
-  ## testing
-  #   table <- table0; whichoutlook="positive"
-  #   table$yi[which(table$outlook=="positive")][1] <- 0.2
-  
+function(table, whichoutlook, smdassigned, smd.noise,...){
+  ## Callers: impute.smd()
+    
   ## extract subset
   subtable <- as.data.frame(table[which(table$outlook==whichoutlook),])
   ## proceed only if subset is not empty
   if(nrow(subtable) != 0) {      
-    # impute smd only if not already imputed
-    subtable[is.na(subtable$yi),]$yi <- smdassigned 
+    numstudies <- nrow(subtable) 
+    
+    ## add random noise
+    smd <- rnorm(numstudies, mean=smdassigned, sd=smd.noise)
+    
+    subtable[is.na(subtable$yi),]$yi <- smd 
     ## replace rows in table
     table[which(table$outlook==whichoutlook),] <- subtable  
   }
